@@ -9,7 +9,9 @@ use Doctrine\DBAL\Platforms\SqlitePlatform;
 use Doctrine\DBAL\Platforms\TrimMode;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 
 use function array_change_key_case;
 use function date;
@@ -19,6 +21,8 @@ use const CASE_LOWER;
 
 class DataAccessTest extends FunctionalTestCase
 {
+    use VerifyDeprecations;
+
     protected function setUp(): void
     {
         $table = new Table('fetch_table');
@@ -139,7 +143,7 @@ class DataAccessTest extends FunctionalTestCase
         $data = $this->connection->fetchAllAssociative(
             $sql,
             [1, $datetime],
-            [ParameterType::STRING, Types::DATETIME_MUTABLE]
+            [ParameterType::STRING, Types::DATETIME_MUTABLE],
         );
 
         self::assertCount(1, $data);
@@ -174,7 +178,7 @@ class DataAccessTest extends FunctionalTestCase
         $row = $this->connection->fetchAssociative(
             $sql,
             [1, $datetime],
-            [ParameterType::STRING, Types::DATETIME_MUTABLE]
+            [ParameterType::STRING, Types::DATETIME_MUTABLE],
         );
 
         self::assertNotFalse($row);
@@ -204,7 +208,7 @@ class DataAccessTest extends FunctionalTestCase
         $row = $this->connection->fetchNumeric(
             $sql,
             [1, $datetime],
-            [ParameterType::STRING, Types::DATETIME_MUTABLE]
+            [ParameterType::STRING, Types::DATETIME_MUTABLE],
         );
 
         self::assertNotFalse($row);
@@ -237,7 +241,7 @@ class DataAccessTest extends FunctionalTestCase
         $column = $this->connection->fetchOne(
             $sql,
             [1, $datetime],
-            [ParameterType::STRING, Types::DATETIME_MUTABLE]
+            [ParameterType::STRING, Types::DATETIME_MUTABLE],
         );
 
         self::assertIsString($column);
@@ -250,7 +254,7 @@ class DataAccessTest extends FunctionalTestCase
         $value = $this->connection->fetchOne(
             'SELECT count(*) AS c FROM fetch_table WHERE test_datetime = ?',
             [new DateTime('2010-01-01 10:10:10')],
-            [Types::DATETIME_MUTABLE]
+            [Types::DATETIME_MUTABLE],
         );
 
         self::assertEquals(1, $value);
@@ -275,7 +279,7 @@ class DataAccessTest extends FunctionalTestCase
         self::assertEquals(1, $this->connection->executeQuery(
             'SELECT count(*) AS c FROM fetch_table WHERE test_datetime = ?',
             [$datetime],
-            [Types::DATETIME_MUTABLE]
+            [Types::DATETIME_MUTABLE],
         )->fetchOne());
     }
 
@@ -302,7 +306,7 @@ class DataAccessTest extends FunctionalTestCase
         $result = $this->connection->executeQuery(
             'SELECT test_int FROM fetch_table WHERE test_int IN (?)',
             [[100, 101, 102, 103, 104]],
-            [Connection::PARAM_INT_ARRAY]
+            [Connection::PARAM_INT_ARRAY],
         );
 
         $data = $result->fetchAllNumeric();
@@ -312,7 +316,7 @@ class DataAccessTest extends FunctionalTestCase
         $result = $this->connection->executeQuery(
             'SELECT test_int FROM fetch_table WHERE test_string IN (?)',
             [['foo100', 'foo101', 'foo102', 'foo103', 'foo104']],
-            [Connection::PARAM_STR_ARRAY]
+            [Connection::PARAM_STR_ARRAY],
         );
 
         $data = $result->fetchAllNumeric();
@@ -338,9 +342,7 @@ class DataAccessTest extends FunctionalTestCase
         self::assertEquals($expectedResult, $row['trimmed']);
     }
 
-    /**
-     * @return array<int, array<int, mixed>>
-     */
+    /** @return array<int, array<int, mixed>> */
     public static function getTrimExpressionData(): iterable
     {
         return [
@@ -467,22 +469,67 @@ class DataAccessTest extends FunctionalTestCase
         $sql .= $platform->getLocateExpression("'barfoobaz'", 'test_string') . ' AS locate6, ';
         $sql .= $platform->getLocateExpression("'bar'", 'test_string') . ' AS locate7, ';
         $sql .= $platform->getLocateExpression('test_string', "'oo'", 2) . ' AS locate8, ';
-        $sql .= $platform->getLocateExpression('test_string', "'oo'", 3) . ' AS locate9 ';
+        $sql .= $platform->getLocateExpression('test_string', "'oo'", 3) . ' AS locate9, ';
+        $sql .= $platform->getLocateExpression('test_string', "'foo'", 1) . ' AS locate10, ';
+        $sql .= $platform->getLocateExpression('test_string', "'oo'", '1 + 1') . ' AS locate11 ';
         $sql .= 'FROM fetch_table';
 
         $row = $this->connection->fetchAssociative($sql);
         self::assertNotFalse($row);
         $row = array_change_key_case($row, CASE_LOWER);
 
-        self::assertEquals(2, $row['locate1']);
-        self::assertEquals(1, $row['locate2']);
-        self::assertEquals(0, $row['locate3']);
-        self::assertEquals(1, $row['locate4']);
-        self::assertEquals(1, $row['locate5']);
-        self::assertEquals(4, $row['locate6']);
-        self::assertEquals(0, $row['locate7']);
-        self::assertEquals(2, $row['locate8']);
-        self::assertEquals(0, $row['locate9']);
+        self::assertEquals([
+            'locate1' => 2,
+            'locate2' => 1,
+            'locate3' => 0,
+            'locate4' => 1,
+            'locate5' => 1,
+            'locate6' => 4,
+            'locate7' => 0,
+            'locate8' => 2,
+            'locate9' => 0,
+            'locate10' => 1,
+            'locate11' => 2,
+        ], $row);
+    }
+
+    public function testSqliteLocateEmulation(): void
+    {
+        if (! TestUtil::isDriverOneOf('pdo_sqlite', 'sqlite3')) {
+            self::markTestSkipped('test is for SQLite only');
+        }
+
+        $sql = <<< 'SQL'
+            SELECT
+                LOCATE(test_string, 'oo') AS locate1,
+                LOCATE(test_string, 'foo') AS locate2,
+                LOCATE(test_string, 'bar') AS locate3,
+                LOCATE(test_string, test_string) AS locate4,
+                LOCATE('foo', test_string) AS locate5,
+                LOCATE('barfoobaz', test_string) AS locate6,
+                LOCATE('bar', test_string) AS locate7,
+                LOCATE(test_string, 'oo', 2) AS locate8,
+                LOCATE(test_string, 'oo', 3) AS locate9,
+                LOCATE(test_string, 'foo', 1) AS locate10,
+                LOCATE(test_string, 'oo', 1 + 1) AS locate11
+            FROM fetch_table
+            SQL;
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/5749');
+
+        self::assertEquals([
+            'locate1' => 2,
+            'locate2' => 1,
+            'locate3' => 0,
+            'locate4' => 1,
+            'locate5' => 1,
+            'locate6' => 4,
+            'locate7' => 0,
+            'locate8' => 2,
+            'locate9' => 0,
+            'locate10' => 1,
+            'locate11' => 2,
+        ], $this->connection->fetchAssociative($sql));
     }
 
     public function testQuoteSQLInjection(): void
