@@ -13,13 +13,11 @@ use Doctrine\DBAL\Platforms\SqlitePlatform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\AbstractAsset;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
-use Doctrine\DBAL\Schema\Column;
-use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
-use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\SchemaDiff;
+use Doctrine\DBAL\Schema\SchemaException;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
@@ -100,9 +98,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertTrue($this->hasElementWithName($this->schemaManager->listSequences(), $name));
     }
 
-    /**
-     * @param AbstractAsset[] $items
-     */
+    /** @param AbstractAsset[] $items */
     private function hasElementWithName(array $items, string $name): bool
     {
         $filteredList = $this->filterElementsByName($items, $name);
@@ -121,7 +117,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
             $items,
             static function (AbstractAsset $item) use ($name): bool {
                 return $item->getShortestName($item->getNamespaceName()) === $name;
-            }
+            },
         );
     }
 
@@ -134,7 +130,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         }
 
         $this->schemaManager->createSequence(
-            new Sequence('list_sequences_test_seq', 20, 10)
+            new Sequence('list_sequences_test_seq', 20, 10),
         );
 
         $sequences = $this->schemaManager->listSequences();
@@ -171,9 +167,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertContains('test_create_database', $databases);
     }
 
-    /**
-     * @dataProvider listSchemaNamesMethodProvider
-     */
+    /** @dataProvider listSchemaNamesMethodProvider */
     public function testListSchemaNames(callable $method): void
     {
         $platform = $this->connection->getDatabasePlatform();
@@ -190,15 +184,13 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertNotContains('test_create_schema', $this->schemaManager->listSchemaNames());
 
         $this->connection->executeStatement(
-            $platform->getCreateSchemaSQL('test_create_schema')
+            $platform->getCreateSchemaSQL('test_create_schema'),
         );
 
         self::assertContains('test_create_schema', $method($this->schemaManager));
     }
 
-    /**
-     * @return iterable<list<mixed>>
-     */
+    /** @return iterable<list<mixed>> */
     public static function listSchemaNamesMethodProvider(): iterable
     {
         yield [
@@ -241,9 +233,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertNull($view);
     }
 
-    /**
-     * @dataProvider tableFilterProvider
-     */
+    /** @dataProvider tableFilterProvider */
     public function testListTablesWithFilter(string $prefix, int $expectedCount): void
     {
         $this->createTestTable('filter_test_1');
@@ -254,22 +244,29 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->connection->getConfiguration()->setSchemaAssetsFilter(
             static function (string $name) use ($prefix): bool {
                 return substr(strtolower($name), 0, strlen($prefix)) === $prefix;
-            }
+            },
         );
 
         self::assertCount($expectedCount, $this->schemaManager->listTableNames());
         self::assertCount($expectedCount, $this->schemaManager->listTables());
     }
 
-    /**
-     * @return iterable<string, array{string, int}>
-     */
+    /** @return iterable<string, array{string, int}> */
     public static function tableFilterProvider(): iterable
     {
         yield 'One table' => ['filter_test_1', 1];
         yield 'Two tables' => ['filter_test_', 2];
     }
 
+    public function testRenameTable(): void
+    {
+        $this->createTestTable('old_name');
+        $this->schemaManager->renameTable('old_name', 'new_name');
+
+        self::assertFalse($this->schemaManager->tablesExist(['old_name']));
+        self::assertTrue($this->schemaManager->tablesExist(['new_name']));
+    }
+
     public function createListTableColumns(): Table
     {
         $table = new Table('list_table_columns');
@@ -444,13 +441,14 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
     {
         if ($this->connection->getDatabasePlatform() instanceof OraclePlatform) {
             self::markTestSkipped(
-                'Does not work with Oracle, since it cannot detect DateTime, Date and Time differences (at the moment).'
+                'Does not work with Oracle,'
+                . ' since it cannot detect DateTime, Date and Time differences (at the moment).',
             );
         }
 
         $offlineTable = $this->createListTableColumns();
         $this->dropAndCreateTable($offlineTable);
-        $onlineTable = $this->schemaManager->listTableDetails('list_table_columns');
+        $onlineTable = $this->schemaManager->introspectTable('list_table_columns');
 
         $diff = $comparatorFactory($this->schemaManager)->diffTable($onlineTable, $offlineTable);
 
@@ -541,7 +539,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->dropAndCreateTable($tableA);
 
-        $fkTable       = $this->schemaManager->listTableDetails('test_create_fk');
+        $fkTable       = $this->schemaManager->introspectTable('test_create_fk');
         $fkConstraints = $fkTable->getForeignKeys();
         self::assertCount(1, $fkConstraints, "Table 'test_create_fk' has to have one foreign key.");
 
@@ -564,7 +562,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
             'test_create_fk2',
             ['id'],
             'foreign_key_test_fk',
-            ['onDelete' => 'CASCADE']
+            ['onDelete' => 'CASCADE'],
         );
 
         $this->schemaManager->createForeignKey($foreignKey, 'test_create_fk1');
@@ -590,13 +588,13 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->createTestTable('test_create_fk1');
         $this->createTestTable('test_create_fk2');
 
-        $table = $this->schemaManager->listTableDetails('test_create_fk1');
+        $table = $this->schemaManager->introspectTable('test_create_fk1');
         $table->addForeignKeyConstraint(
             'test_create_fk2',
             ['foreign_key_test'],
             ['id'],
             [],
-            'i'
+            'i',
         );
         $foreignKey = $table->getForeignKeys()['i'];
         $this->schemaManager->createForeignKey($foreignKey, $table);
@@ -616,11 +614,11 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::markTestSkipped('No Create Example View SQL was defined for this SchemaManager');
     }
 
-    public function testCreateSchema(): void
+    public function testSchemaIntrospection(): void
     {
         $this->createTestTable('test_table');
 
-        $schema = $this->schemaManager->createSchema();
+        $schema = $this->schemaManager->introspectSchema();
         self::assertTrue($schema->hasTable('test_table'));
     }
 
@@ -629,7 +627,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->createTestTable('table_to_alter');
         $this->createTestTable('table_to_drop');
 
-        $schema = $this->schemaManager->createSchema();
+        $schema = $this->schemaManager->introspectSchema();
 
         $tableToAlter = $schema->getTable('table_to_alter');
         $tableToAlter->dropColumn('foreign_key_test');
@@ -643,7 +641,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->migrateSchema($schema);
 
-        $schema = $this->schemaManager->createSchema();
+        $schema = $this->schemaManager->introspectSchema();
 
         self::assertTrue($schema->hasTable('table_to_alter'));
         self::assertFalse($schema->getTable('table_to_alter')->hasColumn('foreign_key_test'));
@@ -658,81 +656,95 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
             self::markTestSkipped('Alter Table is not supported by this platform.');
         }
 
-        $alterTable = $this->createTestTable('alter_table');
+        $this->createTestTable('alter_table');
         $this->createTestTable('alter_table_foreign');
 
-        $table = $this->schemaManager->listTableDetails('alter_table');
+        $table = $this->schemaManager->introspectTable('alter_table');
         self::assertTrue($table->hasColumn('id'));
         self::assertTrue($table->hasColumn('test'));
         self::assertTrue($table->hasColumn('foreign_key_test'));
         self::assertCount(0, $table->getForeignKeys());
         self::assertCount(1, $table->getIndexes());
 
-        $tableDiff                         = new TableDiff('alter_table');
-        $tableDiff->fromTable              = $alterTable;
-        $tableDiff->addedColumns['foo']    = new Column('foo', Type::getType('integer'));
-        $tableDiff->removedColumns['test'] = $table->getColumn('test');
+        $newTable = clone $table;
+        $newTable->addColumn('foo', 'integer');
+        $newTable->dropColumn('test');
 
-        $this->schemaManager->alterTable($tableDiff);
+        $comparator = $this->schemaManager->createComparator();
 
-        $table = $this->schemaManager->listTableDetails('alter_table');
+        $diff = $comparator->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
+
+        $this->schemaManager->alterTable($diff);
+
+        $table = $this->schemaManager->introspectTable('alter_table');
         self::assertFalse($table->hasColumn('test'));
         self::assertTrue($table->hasColumn('foo'));
 
-        $tableDiff                 = new TableDiff('alter_table');
-        $tableDiff->fromTable      = $table;
-        $tableDiff->addedIndexes[] = new Index('foo_idx', ['foo']);
+        $newTable = clone $table;
+        $newTable->addIndex(['foo'], 'foo_idx');
 
-        $this->schemaManager->alterTable($tableDiff);
+        $diff = $comparator->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
 
-        $table = $this->schemaManager->listTableDetails('alter_table');
+        $this->schemaManager->alterTable($diff);
+
+        $table = $this->schemaManager->introspectTable('alter_table');
         self::assertCount(2, $table->getIndexes());
         self::assertTrue($table->hasIndex('foo_idx'));
         self::assertEquals(['foo'], array_map('strtolower', $table->getIndex('foo_idx')->getColumns()));
         self::assertFalse($table->getIndex('foo_idx')->isPrimary());
         self::assertFalse($table->getIndex('foo_idx')->isUnique());
 
-        $tableDiff                   = new TableDiff('alter_table');
-        $tableDiff->fromTable        = $table;
-        $tableDiff->changedIndexes[] = new Index('foo_idx', ['foo', 'foreign_key_test']);
+        $newTable = clone $table;
+        $newTable->dropIndex('foo_idx');
+        $newTable->addIndex(['foo', 'foreign_key_test'], 'foo_idx');
 
-        $this->schemaManager->alterTable($tableDiff);
+        $diff = $comparator->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
 
-        $table = $this->schemaManager->listTableDetails('alter_table');
+        $this->schemaManager->alterTable($diff);
+
+        $table = $this->schemaManager->introspectTable('alter_table');
         self::assertCount(2, $table->getIndexes());
         self::assertTrue($table->hasIndex('foo_idx'));
         self::assertEquals(
             ['foo', 'foreign_key_test'],
-            array_map('strtolower', $table->getIndex('foo_idx')->getColumns())
+            array_map('strtolower', $table->getIndex('foo_idx')->getColumns()),
         );
 
-        $tableDiff                            = new TableDiff('alter_table');
-        $tableDiff->fromTable                 = $table;
-        $tableDiff->renamedIndexes['foo_idx'] = new Index('bar_idx', ['foo', 'foreign_key_test']);
+        $newTable = clone $table;
+        $newTable->dropIndex('foo_idx');
+        $newTable->addIndex(['foo', 'foreign_key_test'], 'bar_idx');
 
-        $this->schemaManager->alterTable($tableDiff);
+        $diff = $comparator->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
 
-        $table = $this->schemaManager->listTableDetails('alter_table');
+        $this->schemaManager->alterTable($diff);
+
+        $table = $this->schemaManager->introspectTable('alter_table');
         self::assertCount(2, $table->getIndexes());
         self::assertTrue($table->hasIndex('bar_idx'));
         self::assertFalse($table->hasIndex('foo_idx'));
         self::assertEquals(
             ['foo', 'foreign_key_test'],
-            array_map('strtolower', $table->getIndex('bar_idx')->getColumns())
+            array_map('strtolower', $table->getIndex('bar_idx')->getColumns()),
         );
         self::assertFalse($table->getIndex('bar_idx')->isPrimary());
         self::assertFalse($table->getIndex('bar_idx')->isUnique());
 
-        $tableDiff                     = new TableDiff('alter_table');
-        $tableDiff->fromTable          = $table;
-        $tableDiff->removedIndexes[]   = new Index('bar_idx', ['foo', 'foreign_key_test']);
-        $fk                            = new ForeignKeyConstraint(['foreign_key_test'], 'alter_table_foreign', ['id']);
-        $tableDiff->addedForeignKeys[] = $fk;
+        $newTable = clone $table;
+        $newTable->dropIndex('bar_idx');
+        $newTable->addForeignKeyConstraint('alter_table_foreign', ['foreign_key_test'], ['id']);
 
-        $this->schemaManager->alterTable($tableDiff);
-        $table = $this->schemaManager->listTableDetails('alter_table');
+        $diff = $comparator->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
 
-        // dont check for index size here, some platforms automatically add indexes for foreign keys.
+        $this->schemaManager->alterTable($diff);
+
+        $table = $this->schemaManager->introspectTable('alter_table');
+
+        // don't check for index size here, some platforms automatically add indexes for foreign keys.
         self::assertFalse($table->hasIndex('bar_idx'));
 
         $fks = $table->getForeignKeys();
@@ -745,7 +757,9 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testTableInNamespace(): void
     {
-        if (! $this->connection->getDatabasePlatform()->supportsSchemas()) {
+        $platform = $this->connection->getDatabasePlatform();
+
+        if (! $platform->supportsSchemas()) {
             self::markTestSkipped('Schema definition is not supported by this platform.');
         }
 
@@ -753,7 +767,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $diff                  = new SchemaDiff();
         $diff->newNamespaces[] = 'testschema';
 
-        foreach ($diff->toSql($this->connection->getDatabasePlatform()) as $sql) {
+        foreach ($platform->getAlterSchemaSQL($diff) as $sql) {
             $this->connection->executeStatement($sql);
         }
 
@@ -804,7 +818,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->createTable($table);
 
-        $inferredTable = $this->schemaManager->listTableDetails('test_autoincrement');
+        $inferredTable = $this->schemaManager->introspectTable('test_autoincrement');
         self::assertTrue($inferredTable->hasColumn('id'));
         self::assertTrue($inferredTable->getColumn('id')->getAutoincrement());
     }
@@ -823,7 +837,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->createTable($table);
 
-        $inferredTable = $this->schemaManager->listTableDetails('test_not_autoincrement');
+        $inferredTable = $this->schemaManager->introspectTable('test_not_autoincrement');
         self::assertTrue($inferredTable->hasColumn('id'));
         self::assertFalse($inferredTable->getColumn('id')->getAutoincrement());
     }
@@ -866,7 +880,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table       = $this->schemaManager->listTableDetails('test_fk_rename');
+        $table       = $this->schemaManager->introspectTable('test_fk_rename');
         $foreignKeys = $table->getForeignKeys();
 
         self::assertTrue($table->hasColumn('rename_fk_id'));
@@ -893,7 +907,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
             ['fk'],
             ['id'],
             [],
-            'fk_constraint'
+            'fk_constraint',
         );
 
         $this->dropTableIfExists($foreignTable->getName());
@@ -910,7 +924,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $foreignTable = $this->schemaManager->listTableDetails('test_rename_index_foreign');
+        $foreignTable = $this->schemaManager->introspectTable('test_rename_index_foreign');
 
         self::assertFalse($foreignTable->hasIndex('rename_index_fk_idx'));
         self::assertTrue($foreignTable->hasIndex('renamed_index_fk_idx'));
@@ -939,23 +953,14 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertCount(1, $columns);
         self::assertEquals('This is a comment', $columns['id']->getComment());
 
-        $tableDiff                       = new TableDiff('column_comment_test');
-        $tableDiff->fromTable            = $table;
-        $tableDiff->changedColumns['id'] = new ColumnDiff(
-            'id',
-            new Column(
-                'id',
-                Type::getType('integer')
-            ),
-            ['comment'],
-            new Column(
-                'id',
-                Type::getType('integer'),
-                ['comment' => 'This is a comment']
-            )
-        );
+        $newTable = clone $table;
+        $newTable->changeColumn('id', ['comment' => null]);
 
-        $this->schemaManager->alterTable($tableDiff);
+        $diff = $this->schemaManager->createComparator()
+            ->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
+
+        $this->schemaManager->alterTable($diff);
 
         $columns = $this->schemaManager->listTableColumns('column_comment_test');
         self::assertCount(1, $columns);
@@ -1027,23 +1032,15 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $tableDiff                            = new TableDiff($tableName);
-        $tableDiff->fromTable                 = $table;
-        $tableDiff->changedColumns['col_int'] = new ColumnDiff(
-            'col_int',
-            new Column('col_int', Type::getType('integer'), ['default' => 666]),
-            ['type'],
-            new Column('col_int', Type::getType('smallint'), ['default' => 666])
-        );
+        $newTable = clone $table;
+        $newTable->changeColumn('col_int', ['type' => Type::getType('integer')]);
+        $newTable->changeColumn('col_string', ['fixed' => true]);
 
-        $tableDiff->changedColumns['col_string'] = new ColumnDiff(
-            'col_string',
-            new Column('col_string', Type::getType('string'), ['default' => 'foo', 'fixed' => true]),
-            ['fixed'],
-            new Column('col_string', Type::getType('string'), ['default' => 'foo'])
-        );
+        $diff = $this->schemaManager->createComparator()
+            ->diffTable($table, $newTable);
+        self::assertNotFalse($diff);
 
-        $this->schemaManager->alterTable($tableDiff);
+        $this->schemaManager->alterTable($diff);
 
         $columns = $this->schemaManager->listTableColumns($tableName);
 
@@ -1061,15 +1058,13 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->createTable($table);
 
-        $created = $this->schemaManager->listTableDetails('test_blob_table');
+        $created = $this->schemaManager->introspectTable('test_blob_table');
 
         self::assertTrue($created->hasColumn('binarydata'));
         self::assertInstanceOf(BlobType::class, $created->getColumn('binarydata')->getType());
     }
 
-    /**
-     * @param mixed[] $data
-     */
+    /** @param mixed[] $data */
     protected function createTestTable(string $name = 'test_table', array $data = []): Table
     {
         $options = $data['options'] ?? [];
@@ -1081,9 +1076,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         return $table;
     }
 
-    /**
-     * @param mixed[] $options
-     */
+    /** @param mixed[] $options */
     protected function getTestTable(string $name, array $options = []): Table
     {
         $table = new Table($name, [], [], [], [], $options);
@@ -1108,9 +1101,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         return $table;
     }
 
-    /**
-     * @param Table[] $tables
-     */
+    /** @param Table[] $tables */
     protected function assertHasTable(array $tables): void
     {
         $foundTable = false;
@@ -1135,7 +1126,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
             ['id', 'foreign_key_test'],
             'test_create_fk4',
             ['id', 'other_id'],
-            'foreign_key_test_fk2'
+            'foreign_key_test_fk2',
         );
 
         $this->schemaManager->createForeignKey($foreignKey, 'test_create_fk3');
@@ -1216,7 +1207,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->createTable($table);
 
-        $table = $this->schemaManager->listTableDetails($tableName);
+        $table = $this->schemaManager->introspectTable($tableName);
         $this->assertBinaryColumnIsValid($table, 'column_binary', 16);
         $this->assertVarBinaryColumnIsValid($table, 'column_varbinary', 32);
     }
@@ -1237,6 +1228,12 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertFalse($column->getFixed());
     }
 
+    public function testGetNonExistingTable(): void
+    {
+        $this->expectException(SchemaException::class);
+        $this->schemaManager->introspectTable('non_existing');
+    }
+
     public function testListTableDetailsWithFullQualifiedTableName(): void
     {
         if (! $this->connection->getDatabasePlatform()->supportsSchemas()) {
@@ -1265,15 +1262,15 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         self::assertEquals(
             $this->schemaManager->listTableColumns($primaryTableName),
-            $this->schemaManager->listTableColumns($defaultSchemaName . '.' . $primaryTableName)
+            $this->schemaManager->listTableColumns($defaultSchemaName . '.' . $primaryTableName),
         );
         self::assertEquals(
             $this->schemaManager->listTableIndexes($primaryTableName),
-            $this->schemaManager->listTableIndexes($defaultSchemaName . '.' . $primaryTableName)
+            $this->schemaManager->listTableIndexes($defaultSchemaName . '.' . $primaryTableName),
         );
         self::assertEquals(
             $this->schemaManager->listTableForeignKeys($primaryTableName),
-            $this->schemaManager->listTableForeignKeys($defaultSchemaName . '.' . $primaryTableName)
+            $this->schemaManager->listTableForeignKeys($defaultSchemaName . '.' . $primaryTableName),
         );
     }
 
@@ -1318,7 +1315,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $columnDefinition = substr(
             $this->connection->getDatabasePlatform()->getColumnDeclarationSQL('id', $options),
-            strlen('id') + 1
+            strlen('id') + 1,
         );
 
         $table = new Table('my_table');
@@ -1362,7 +1359,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $offlineTable->addColumn('no_comment2', 'integer');
         $this->dropAndCreateTable($offlineTable);
 
-        $onlineTable = $this->schemaManager->listTableDetails('alter_column_comment_test');
+        $onlineTable = $this->schemaManager->introspectTable('alter_column_comment_test');
 
         self::assertSame($expectedComment1, $onlineTable->getColumn('comment1')->getComment());
         self::assertSame($expectedComment2, $onlineTable->getColumn('comment2')->getComment());
@@ -1380,7 +1377,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->schemaManager->alterTable($tableDiff);
 
-        $onlineTable = $this->schemaManager->listTableDetails('alter_column_comment_test');
+        $onlineTable = $this->schemaManager->introspectTable('alter_column_comment_test');
 
         self::assertSame($expectedComment2, $onlineTable->getColumn('comment1')->getComment());
         self::assertSame($expectedComment1, $onlineTable->getColumn('comment2')->getComment());
@@ -1388,9 +1385,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertSame($expectedComment2, $onlineTable->getColumn('no_comment2')->getComment());
     }
 
-    /**
-     * @return iterable<mixed[]>
-     */
+    /** @return iterable<mixed[]> */
     public static function getAlterColumnComment(): iterable
     {
         foreach (ComparatorTestUtils::comparatorProvider() as $comparatorArguments) {
@@ -1458,14 +1453,12 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $table->addColumn('parameters', 'json');
 
         $tableDiff = $comparatorFactory($this->schemaManager)
-            ->diffTable($this->schemaManager->listTableDetails('json_test'), $table);
+            ->diffTable($this->schemaManager->introspectTable('json_test'), $table);
 
         self::assertFalse($tableDiff);
     }
 
-    /**
-     * @dataProvider commentsProvider
-     */
+    /** @dataProvider commentsProvider */
     public function testExtractDoctrineTypeFromComment(string $comment, string $expected, string $currentType): void
     {
         $result = $this->schemaManager->extractDoctrineTypeFromComment($comment, $currentType);
@@ -1473,9 +1466,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertSame($expected, $result);
     }
 
-    /**
-     * @return string[][]
-     */
+    /** @return string[][] */
     public function commentsProvider(): array
     {
         $currentType = 'current type';
@@ -1556,8 +1547,8 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
                 $this->schemaManager->listSequences(),
                 static function (Sequence $sequence) use ($sequenceName): bool {
                     return strcasecmp($sequence->getName(), $sequenceName) === 0;
-                }
-            )
+                },
+            ),
         )[0] ?? null;
 
         self::assertNotNull($createdSequence);
@@ -1578,7 +1569,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->connection->insert('test_pk_auto_increment', ['text' => '1']);
 
         $lastUsedIdBeforeDelete = (int) $this->connection->fetchOne(
-            "SELECT id FROM test_pk_auto_increment WHERE text = '1'"
+            "SELECT id FROM test_pk_auto_increment WHERE text = '1'",
         );
 
         $this->connection->executeStatement('DELETE FROM test_pk_auto_increment');
@@ -1586,7 +1577,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->connection->insert('test_pk_auto_increment', ['text' => '2']);
 
         $lastUsedIdAfterDelete = (int) $this->connection->fetchOne(
-            "SELECT id FROM test_pk_auto_increment WHERE text = '2'"
+            "SELECT id FROM test_pk_auto_increment WHERE text = '2'",
         );
 
         self::assertGreaterThan($lastUsedIdBeforeDelete, $lastUsedIdAfterDelete);
@@ -1596,7 +1587,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
     {
         if (! $this->connection->getDatabasePlatform()->supportsColumnLengthIndexes()) {
             self::markTestSkipped(
-                'This test is only supported on platforms that support indexes with column length definitions.'
+                'This test is only supported on platforms that support indexes with column length definitions.',
             );
         }
 
@@ -1610,7 +1601,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->listTableDetails('test_partial_column_index');
+        $onlineTable = $this->schemaManager->introspectTable('test_partial_column_index');
         self::assertEquals($expected, $onlineTable->getIndexes());
     }
 
@@ -1621,7 +1612,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $table->setComment('Foo with control characters \'\\');
         $this->dropAndCreateTable($table);
 
-        $table = $this->schemaManager->listTableDetails('table_with_comment');
+        $table = $this->schemaManager->introspectTable('table_with_comment');
         self::assertSame('Foo with control characters \'\\', $table->getComment());
     }
 
@@ -1656,12 +1647,12 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
             $localColumns,
             $foreignColumns,
             [],
-            $foreignKey
+            $foreignKey,
         );
 
         $this->schemaManager->createTable($table);
 
-        $table = $this->schemaManager->listTableDetails($foreignTable);
+        $table = $this->schemaManager->introspectTable($foreignTable);
 
         $foreignKey = $table->getForeignKey($foreignKey);
 
@@ -1673,7 +1664,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
     {
         $this->createReservedKeywordTables();
 
-        $user = $this->schemaManager->listTableDetails('"user"');
+        $user = $this->schemaManager->introspectTable('"user"');
         self::assertCount(2, $user->getColumns());
         self::assertCount(2, $user->getIndexes());
         self::assertCount(1, $user->getForeignKeys());
@@ -1715,9 +1706,93 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $schemaManager->createSchemaObjects($schema);
     }
 
-    /**
-     * @param list<Table> $tables
-     */
+    public function testChangeIndexWithForeignKeys(): void
+    {
+        $this->dropTableIfExists('child');
+        $this->dropTableIfExists('parent');
+
+        $schema = new Schema();
+
+        $parent = $schema->createTable('parent');
+        $parent->addColumn('id', 'integer');
+        $parent->setPrimaryKey(['id']);
+
+        $child = $schema->createTable('child');
+        $child->addColumn('id', 'integer');
+        $child->addColumn('parent_id', 'integer');
+        $child->addIndex(['parent_id'], 'idx_1');
+        $child->addForeignKeyConstraint('parent', ['parent_id'], ['id']);
+
+        $schemaManager = $this->connection->createSchemaManager();
+        $schemaManager->createSchemaObjects($schema);
+
+        $child->dropIndex('idx_1');
+        $child->addIndex(['parent_id'], 'idx_2');
+
+        $diff = $schemaManager->createComparator()->diffTable(
+            $schemaManager->introspectTable('child'),
+            $child,
+        );
+        self::assertNotFalse($diff);
+
+        $schemaManager->alterTable($diff);
+
+        $child = $schemaManager->introspectTable('child');
+
+        self::assertFalse($child->hasIndex('idx_1'));
+        self::assertTrue($child->hasIndex('idx_2'));
+    }
+
+    public function testSwitchPrimaryKeyOrder(): void
+    {
+        $prototype = new Table('test_switch_pk_order');
+        $prototype->addColumn('foo_id', 'integer');
+        $prototype->addColumn('bar_id', 'integer');
+
+        $table = clone $prototype;
+        $table->setPrimaryKey(['foo_id', 'bar_id']);
+        $this->dropAndCreateTable($table);
+
+        $table = clone $prototype;
+        $table->setPrimaryKey(['bar_id', 'foo_id']);
+
+        $schemaManager = $this->connection->createSchemaManager();
+
+        $diff = $schemaManager->createComparator()->diffTable(
+            $schemaManager->introspectTable('test_switch_pk_order'),
+            $table,
+        );
+        self::assertNotFalse($diff);
+
+        $table      = $schemaManager->introspectTable('test_switch_pk_order');
+        $primaryKey = $table->getPrimaryKey();
+        self::assertNotNull($primaryKey);
+        self::assertSame(['foo_id', 'bar_id'], array_map('strtolower', $primaryKey->getColumns()));
+    }
+
+    public function testDropColumnWithDefault(): void
+    {
+        $table = new Table('drop_column_with_default');
+        $table->addColumn('id', 'integer');
+        $table->addColumn('todrop', 'decimal', ['default' => 10.2]);
+
+        $this->dropAndCreateTable($table);
+
+        $table->dropColumn('todrop');
+
+        $diff = $this->schemaManager->createComparator()
+            ->diffTable(
+                $this->schemaManager->introspectTable('drop_column_with_default'),
+                $table,
+            );
+        self::assertNotFalse($diff);
+        $this->schemaManager->alterTable($diff);
+
+        $columns = $this->schemaManager->listTableColumns('drop_column_with_default');
+        self::assertCount(1, $columns);
+    }
+
+    /** @param list<Table> $tables */
     protected function findTableByName(array $tables, string $name): ?Table
     {
         foreach ($tables as $table) {
