@@ -19,14 +19,10 @@ use function sprintf;
 use function strtoupper;
 use function uniqid;
 
-/**
- * @extends AbstractPlatformTestCase<OraclePlatform>
- */
+/** @extends AbstractPlatformTestCase<OraclePlatform> */
 class OraclePlatformTest extends AbstractPlatformTestCase
 {
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function dataValidIdentifiers(): iterable
     {
         return [
@@ -42,9 +38,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * @dataProvider dataValidIdentifiers
-     */
+    /** @dataProvider dataValidIdentifiers */
     public function testValidIdentifiers(string $identifier): void
     {
         $platform = $this->createPlatform();
@@ -53,9 +47,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         $this->expectNotToPerformAssertions();
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function dataInvalidIdentifiers(): iterable
     {
         return [
@@ -67,9 +59,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * @dataProvider dataInvalidIdentifiers
-     */
+    /** @dataProvider dataInvalidIdentifiers */
     public function testInvalidIdentifiers(string $identifier): void
     {
         $this->expectException(Exception::class);
@@ -99,20 +89,6 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getGenerateAlterTableSql(): array
-    {
-        return [
-            'ALTER TABLE mytable ADD (quota NUMBER(10) DEFAULT NULL NULL)',
-            "ALTER TABLE mytable MODIFY (baz VARCHAR2(255) DEFAULT 'def' NOT NULL, "
-                . 'bloo NUMBER(1) DEFAULT 0 NOT NULL)',
-            'ALTER TABLE mytable DROP (foo)',
-            'ALTER TABLE mytable RENAME TO userlist',
-        ];
-    }
-
     public function testRLike(): void
     {
         $this->expectException(Exception::class);
@@ -125,7 +101,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         self::assertEquals('"', $this->platform->getIdentifierQuoteCharacter());
         self::assertEquals(
             'column1 || column2 || column3',
-            $this->platform->getConcatExpression('column1', 'column2', 'column3')
+            $this->platform->getConcatExpression('column1', 'column2', 'column3'),
         );
     }
 
@@ -133,19 +109,19 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_UNCOMMITTED)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_UNCOMMITTED),
         );
         self::assertEquals(
             'SET TRANSACTION ISOLATION LEVEL READ COMMITTED',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_COMMITTED)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_COMMITTED),
         );
         self::assertEquals(
             'SET TRANSACTION ISOLATION LEVEL SERIALIZABLE',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::REPEATABLE_READ)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::REPEATABLE_READ),
         );
         self::assertEquals(
             'SET TRANSACTION ISOLATION LEVEL SERIALIZABLE',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::SERIALIZABLE)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::SERIALIZABLE),
         );
     }
 
@@ -168,17 +144,17 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'NUMBER(10)',
-            $this->platform->getIntegerTypeDeclarationSQL([])
+            $this->platform->getIntegerTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'NUMBER(10)',
-            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'NUMBER(10)',
             $this->platform->getIntegerTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
     }
 
@@ -187,16 +163,16 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         self::assertEquals(
             'CHAR(10)',
             $this->platform->getStringTypeDeclarationSQL(
-                ['length' => 10, 'fixed' => true]
-            )
+                ['length' => 10, 'fixed' => true],
+            ),
         );
         self::assertEquals(
             'VARCHAR2(50)',
-            $this->platform->getStringTypeDeclarationSQL(['length' => 50])
+            $this->platform->getStringTypeDeclarationSQL(['length' => 50]),
         );
         self::assertEquals(
             'VARCHAR2(255)',
-            $this->platform->getStringTypeDeclarationSQL([])
+            $this->platform->getStringTypeDeclarationSQL([]),
         );
     }
 
@@ -247,9 +223,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         self::assertSame($expectedSql, $this->platform->getAdvancedForeignKeyOptionsSQL($foreignKey));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getGeneratesAdvancedForeignKeyOptionsSQLData(): iterable
     {
         return [
@@ -296,7 +270,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
             'SELECT * FROM ('
                 . 'SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a WHERE ROWNUM <= 20'
                 . ') WHERE doctrine_rownum >= 11',
-            $sql
+            $sql,
         );
     }
 
@@ -308,7 +282,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
             'SELECT * FROM ('
                 . 'SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a'
                 . ') WHERE doctrine_rownum >= 11',
-            $sql
+            $sql,
         );
     }
 
@@ -352,11 +326,11 @@ SQL
                 $tableName,
                 $tableName,
                 $tableName,
-                $columnName
+                $columnName,
             ),
             sprintf('CREATE SEQUENCE %s_SEQ START WITH 1 MINVALUE 1 INCREMENT BY 1', $tableName),
             sprintf(
-                <<<SQL
+                <<<'SQL'
 CREATE TRIGGER %s_AI_PK
    BEFORE INSERT
    ON %s
@@ -389,7 +363,7 @@ SQL
                 $tableName,
                 $columnName,
                 $tableName,
-                $tableName
+                $tableName,
             ),
         ], $this->platform->getCreateTableSQL($table));
     }
@@ -497,27 +471,27 @@ SQL
             new Column(
                 'foo',
                 Type::getType('string'),
-                ['default' => 'bla', 'notnull' => true]
+                ['default' => 'bla', 'notnull' => true],
             ),
-            ['type']
+            ['type'],
         );
         $tableDiff->changedColumns['bar']   = new ColumnDiff(
             'bar',
             new Column(
                 'baz',
                 Type::getType('string'),
-                ['default' => 'bla', 'notnull' => true]
+                ['default' => 'bla', 'notnull' => true],
             ),
-            ['type', 'notnull']
+            ['type', 'notnull'],
         );
         $tableDiff->changedColumns['metar'] = new ColumnDiff(
             'metar',
             new Column(
                 'metar',
                 Type::getType('string'),
-                ['length' => 2000, 'notnull' => false]
+                ['length' => 2000, 'notnull' => false],
             ),
-            ['notnull']
+            ['notnull'],
         );
 
         $expectedSql = [
@@ -556,7 +530,7 @@ SQL
 
         self::assertSame(
             'RAW(2000)',
-            $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2000])
+            $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2000]),
         );
     }
 
@@ -592,18 +566,14 @@ SQL
         self::assertSame('"mytable_SEQ"', $this->platform->getIdentitySequenceName('"mytable"', '"mycolumn"'));
     }
 
-    /**
-     * @dataProvider dataCreateSequenceWithCache
-     */
+    /** @dataProvider dataCreateSequenceWithCache */
     public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql): void
     {
         $sequence = new Sequence('foo', 1, 1, $cacheSize);
         self::assertStringContainsString($expectedSql, $this->platform->getCreateSequenceSQL($sequence));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function dataCreateSequenceWithCache(): iterable
     {
         return [
@@ -705,9 +675,7 @@ SQL
         self::assertSame($expectedSql, $this->platform->getDropAutoincrementSql($table));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getReturnsDropAutoincrementSQL(): iterable
     {
         return [
@@ -738,24 +706,6 @@ SQL
         ];
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesTableIdentifiersInAlterTableSQL(): array
-    {
-        return [
-            'ALTER TABLE "foo" DROP CONSTRAINT fk1',
-            'ALTER TABLE "foo" DROP CONSTRAINT fk2',
-            'ALTER TABLE "foo" ADD (bloo NUMBER(10) NOT NULL)',
-            'ALTER TABLE "foo" MODIFY (bar NUMBER(10) DEFAULT NULL NULL)',
-            'ALTER TABLE "foo" RENAME COLUMN id TO war',
-            'ALTER TABLE "foo" DROP (baz)',
-            'ALTER TABLE "foo" RENAME TO "table"',
-            'ALTER TABLE "table" ADD CONSTRAINT fk_add FOREIGN KEY (fk3) REFERENCES fk_table (id)',
-            'ALTER TABLE "table" ADD CONSTRAINT fk2 FOREIGN KEY (fk2) REFERENCES fk_table2 (id)',
-        ];
-    }
-
     /**
      * {@inheritdoc}
      */
@@ -780,7 +730,7 @@ SQL
         self::assertInstanceOf(TableDiff::class, $tableDiff);
         self::assertSame(
             ['COMMENT ON COLUMN "foo"."bar" IS \'baz\''],
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
@@ -797,7 +747,7 @@ SQL
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals('CREATE TABLE "test" ("id" NUMBER(10) NOT NULL)', $sql[0]);
         self::assertEquals('CREATE SEQUENCE "test_SEQ" START WITH 1 MINVALUE 1 INCREMENT BY 1', $sql[2]);
-        $createTriggerStatement = <<<EOD
+        $createTriggerStatement = <<<'EOD'
 CREATE TRIGGER "test_AI_PK"
    BEFORE INSERT
    ON "test"
@@ -824,9 +774,7 @@ EOD;
         self::assertEquals($createTriggerStatement, $sql[3]);
     }
 
-    /**
-     * @dataProvider getReturnsGetListTableColumnsSQL
-     */
+    /** @dataProvider getReturnsGetListTableColumnsSQL */
     public function testReturnsGetListTableColumnsSQL(?string $database, string $expectedSql): void
     {
         // note: this assertion is a bit strict, as it compares a full SQL string.
@@ -835,9 +783,7 @@ EOD;
         self::assertEquals($expectedSql, $this->platform->getListTableColumnsSQL('"test"', $database));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getReturnsGetListTableColumnsSQL(): iterable
     {
         return [
@@ -927,7 +873,7 @@ SQL
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListSequencesSQL("Foo'Bar\\")
+            $this->platform->getListSequencesSQL("Foo'Bar\\"),
         );
     }
 
@@ -935,7 +881,7 @@ SQL
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableIndexesSQL("Foo'Bar\\")
+            $this->platform->getListTableIndexesSQL("Foo'Bar\\"),
         );
     }
 
@@ -943,7 +889,7 @@ SQL
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\")
+            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\"),
         );
     }
 
@@ -951,7 +897,7 @@ SQL
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableConstraintsSQL("Foo'Bar\\")
+            $this->platform->getListTableConstraintsSQL("Foo'Bar\\"),
         );
     }
 
@@ -959,7 +905,7 @@ SQL
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL("Foo'Bar\\")
+            $this->platform->getListTableColumnsSQL("Foo'Bar\\"),
         );
     }
 
@@ -967,13 +913,11 @@ SQL
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL('foo_table', "Foo'Bar\\")
+            $this->platform->getListTableColumnsSQL('foo_table', "Foo'Bar\\"),
         );
     }
 
-    /**
-     * @return array<int, array{string, array<string, mixed>}>
-     */
+    /** @return array<int, array{string, array<string, mixed>}> */
     public function asciiStringSqlDeclarationDataProvider(): array
     {
         return [
